@@ -29,10 +29,13 @@ class AccreditationCircuits:
     """
     This class generates accreditation circuits from a target.
 
-    Implementation follows the methods from
-    Samuele Ferracin, Theodoros Kapourniotis and Animesh Datta
-    New Journal of Physics, Volume 21, November 2019
-    https://iopscience.iop.org/article/10.1088/1367-2630/ab4fd6
+    Implementation follows the methods from [1]
+
+    References:
+        1. S. Ferracin, T. Kapourniotis, A. Datta.
+           *Accrediting outputs of noisy intermediate-scale quantum computing devices*,
+           New Journal of Physics, Volume 21, 113038. (2019).
+           `NJP 113038 <https://iopscience.iop.org/article/10.1088/1367-2630/ab4fd6>`_
     """
     def __init__(self, target_circ, two_qubit_gate='cx', coupling_map=None, seed=None):
         """
