@@ -20,12 +20,16 @@ randomized model circuits", arXiv:1811.12926
 """
 
 import math
+import warnings
 import numpy as np
 from qiskit import QiskitError
+from qiskit.visualization import plot_histogram
 from ...utils import build_counts_dict_from_list
 
 try:
+    from matplotlib import get_backend
     from matplotlib import pyplot as plt
+    from matplotlib.patches import Rectangle
     HAS_MATPLOTLIB = True
 except ImportError:
     HAS_MATPLOTLIB = False
@@ -51,7 +55,10 @@ class QVFitter:
         self._result_list = []
         self._heavy_output_counts = {}
         self._circ_shots = {}
+        self._circ_counts = {}
+        self._all_output_prob_ideal = {}
         self._heavy_output_prob_ideal = {}
+        self._heavy_output_prob_exp = {}
         self._ydata = []
         self._heavy_outputs = {}
         self.add_statevectors(statevector_result)
@@ -114,32 +121,32 @@ class QVFitter:
         for result in new_statevector_result:
             for qvcirc in result.results:
 
-                circname = qvcirc.header.name
+                circ_name = qvcirc.header.name
 
                 # get the depth/width from the circuit name
                 # qv_depth_%d_trial_%d
-                depth = int(circname.split('_')[2])
+                depth = int(circ_name.split('_')[2])
 
-                if circname in self._heavy_outputs:
+                if circ_name in self._heavy_outputs:
                     raise QiskitError("Already added the ideal result "
-                                      "for circuit %s" % circname)
+                                      "for circuit %s" % circ_name)
 
                 # convert the result into probability dictionary
-                qstate = result.get_statevector(circname)
+                qstate = result.get_statevector(circ_name)
                 pvector = np.multiply(qstate, qstate.conjugate())
                 format_spec = "{0:0%db}" % depth
-                pmap = {format_spec.format(b):
-                        float(np.real(pvector[b]))
-                        for b in range(2**depth)}
-                median_prob = self._median_probabilities([pmap])
-                self._heavy_outputs[qvcirc.header.name] = \
-                    self._heavy_strings(pmap, median_prob[0])
+                self._all_output_prob_ideal[circ_name] = \
+                    {format_spec.format(b): float(np.real(pvector[b])) for b in range(2**depth)}
+
+                median_prob = self._median_probabilities([self._all_output_prob_ideal[circ_name]])
+                self._heavy_outputs[circ_name] = \
+                    self._heavy_strings(self._all_output_prob_ideal[circ_name], median_prob[0])
 
                 # calculate the heavy output probability
-                self._heavy_output_prob_ideal[circname] = \
+                self._heavy_output_prob_ideal[circ_name] = \
                     self._subset_probability(
-                        self._heavy_outputs[circname],
-                        pmap)
+                        self._heavy_outputs[circ_name],
+                        self._all_output_prob_ideal[circ_name])
 
     def add_data(self, new_backend_result, rerun_fit=True):
         """
@@ -192,7 +199,6 @@ class QVFitter:
             the output of circuits generated by qv_circuits,
         """
 
-        circ_counts = {}
         for trialidx in range(self._ntrials):
             for _, depth in enumerate(self._depths):
                 circ_name = 'qv_depth_%d_trial_%d' % (depth, trialidx)
@@ -205,24 +211,35 @@ class QVFitter:
                     except (QiskitError, KeyError):
                         pass
 
-                circ_counts[circ_name] = \
+                self._circ_counts[circ_name] = \
                     build_counts_dict_from_list(count_list)
 
                 self._circ_shots[circ_name] = \
-                    sum(circ_counts[circ_name].values())
+                    sum(self._circ_counts[circ_name].values())
 
-                # calculate the heavy output probability
+                # calculate the experimental heavy output counts
                 self._heavy_output_counts[circ_name] = \
                     self._subset_probability(
                         self._heavy_outputs[circ_name],
-                        circ_counts[circ_name])
+                        self._circ_counts[circ_name])
+
+                # calculate the experimental heavy output probability
+                self._heavy_output_prob_exp[circ_name] = \
+                    self._heavy_output_counts[circ_name]/self._circ_shots[circ_name]
+
+                # calculate the experimental heavy output probability
+                self._heavy_output_prob_exp[circ_name] = \
+                    self._heavy_output_counts[circ_name] / self._circ_shots[circ_name]
 
     def calc_statistics(self):
         """
         Convert the heavy outputs in the different trials into mean and error
         for plotting.
 
-        Here we assume the error is due to a binomial distribution
+        Here we assume the error is due to a binomial distribution.
+        Error (standard deviation) for binomial distribution is sqrt(np(1-p)),
+        where n is the number of trials (self._ntrials) and
+        p is the success probability (self._ydata[0][depthidx]/self._ntrials).
         """
 
         self._ydata = np.zeros([4, len(self._depths)], dtype=float)
@@ -240,25 +257,36 @@ class QVFitter:
                 exp_shots += self._circ_shots[cname]
                 ideal_vals[trialidx] = self._heavy_output_prob_ideal[cname]
 
+            # Calculate mean and error for experimental data
             self._ydata[0][depthidx] = np.sum(exp_vals)/np.sum(exp_shots)
             self._ydata[1][depthidx] = (self._ydata[0][depthidx] *
                                         (1.0-self._ydata[0][depthidx])
                                         / self._ntrials)**0.5
+
+            # Calculate mean and error for ideal data
             self._ydata[2][depthidx] = np.mean(ideal_vals)
             self._ydata[3][depthidx] = (self._ydata[2][depthidx] *
                                         (1.0-self._ydata[2][depthidx])
                                         / self._ntrials)**0.5
 
-    def plot_qv_data(self, ax=None, show_plt=True):
-        """
-        Plot the qv data as a function of depth
+    def plot_qv_data(self, ax=None, show_plt=True, figsize=(7, 5), set_title=True, title=None):
+        """Plot the qv data as a function of depth
 
         Args:
             ax (Axes or None): plot axis (if passed in).
             show_plt (bool): display the plot.
+            figsize (tuple): Figure size in inches.
+            set_title (bool): set figure title.
+            title (String or None): text for setting figure title
 
         Raises:
             ImportError: If matplotlib is not installed.
+
+        Returns:
+            matplotlib.Figure:
+                A figure of Quantum Volume data (heavy
+                output probability) with two-sigma error
+                bar as a function of circuit depth.
         """
 
         if not HAS_MATPLOTLIB:
@@ -266,68 +294,239 @@ class QVFitter:
                               'Run "pip install matplotlib" before.')
 
         if ax is None:
-            plt.figure()
-            ax = plt.gca()
+            fig, ax = plt.subplots(figsize=figsize)
+        else:
+            fig = None
 
         xdata = range(len(self._depths))
 
         # Plot the experimental data with error bars
         ax.errorbar(xdata, self._ydata[0],
-                    yerr=self._ydata[1],
-                    color='r', linestyle=None, marker='o', markersize=5,
-                    label='Exp')
+                    yerr=self._ydata[1]*2,
+                    color='r', marker='o',
+                    markersize=6, capsize=5,
+                    elinewidth=2, label='Exp (2$\\sigma$ error)')
 
         # Plot the ideal data with error bars
         ax.errorbar(xdata, self._ydata[2],
-                    yerr=self._ydata[3],
-                    color='b', linestyle=None, marker='o', markersize=5,
-                    label='Ideal')
+                    yerr=self._ydata[3]*2,
+                    color='b', marker='v',
+                    markersize=6, capsize=5,
+                    elinewidth=2, label='Ideal (2$\\sigma$ error)')
 
         # Plot the threshold
-        ax.plot(xdata,
-                np.ones(len(xdata))*2.0/3.0,
-                color='black', linestyle='--', linewidth=2, label='Threshold')
-        ax.tick_params(labelsize=14)
+        ax.axhline(2/3, color='k', linestyle='dashed', linewidth=1, label='Threshold')
 
         ax.set_xticks(xdata)
         ax.set_xticklabels(self._qubit_lists, rotation=45)
 
-        ax.set_xlabel('Qubit Subset', fontsize=16)
-        ax.set_ylabel('Heavy Probability', fontsize=16)
+        ax.set_xlabel('Qubit Subset', fontsize=14)
+        ax.set_ylabel('Heavy Output Probability', fontsize=14)
         ax.grid(True)
 
         ax.legend()
 
+        if set_title:
+            if title is None:
+                title = (
+                    f'Quantum Volume for up to {len(self._qubit_lists[-1])} Qubits '
+                    f'and {self._ntrials} Trials')
+            ax.set_title(title)
+
+        if fig:
+            if get_backend() in ['module://ipykernel.pylab.backend_inline',
+                                 'nbAgg']:
+                plt.close(fig)
+
         if show_plt:
             plt.show()
 
-    def qv_success(self):
-        """Return whether each depth was successful (>2/3 with confidence
-        greater than 97.5) and the confidence
+        return fig
+
+    def plot_qv_trial(self, depth, trial_index, figsize=(7, 5), ax=None):
+        """Plot individual trial.
+        Args:
+            depth(int): circuit depth
+            trial_index(int): trial index
+            figsize (tuple): Figure size in inches.
+            ax (Axes or None): plot axis (if passed in).
 
         Returns:
-            list: List of lenth depth with eact element a 3 list with
+            matplotlib.Figure:
+                A figure for histogram of ideal and experiment probabilities.
+        """
+        circ_name = f"qv_depth_{depth}_trial_{trial_index}"
+        ideal_data = self._all_output_prob_ideal[circ_name]
+        exp_data = self._circ_counts[circ_name]
+
+        if ax is None:
+            fig, ax = plt.subplots(figsize=figsize)
+        else:
+            fig = None
+
+        # plot experimental histogram
+        plot_histogram(exp_data, legend=['Exp'], ax=ax)
+
+        # plot idea histogram overlap with experimental values
+        plot_histogram(ideal_data, legend=['Ideal'], bar_labels=False, ax=ax, color='r')
+
+        # get ideal histograms and change to unfilled
+        bars = [r for r in ax.get_children() if isinstance(r, Rectangle)]
+        for i in range(int(len(bars)/2), len(bars)-1):
+            bars[i].fill = False
+            # set non-black edge color to increase bar labels legibility
+            bars[i].set_edgecolor('saddlebrown')
+
+        # show experimental heavy output probability to the legend
+        ax.plot([], [], ' ', label=f'HOP~{self._heavy_output_prob_exp[circ_name]:.3f}')
+
+        # plot median probability
+        median_prob = self._median_probabilities([self._all_output_prob_ideal[circ_name]])
+        ax.axhline(median_prob, color='r', linestyle='dashed', linewidth=1, label='Median')
+        ax.legend()
+        ax.set_title(f'Quantum Volume {2**depth}, Trial #{trial_index}', fontsize=14)
+
+        # Only close mpl figures in jupyter with inline backends
+        if get_backend() in ['module://ipykernel.pylab.backend_inline',
+                             'nbAgg']:
+            plt.close(fig)
+
+        return fig
+
+    def plot_hop_accumulative(self, depth, ax=None, figsize=(7, 5)):
+        """Plot individual and accumulative heavy output probability (HOP)
+        as a function of number of trials.
+
+        Args:
+            depth (int): depth of QV circuits
+            ax (Axes or None): plot axis (if passed in).
+            figsize (tuple): figure size in inches.
+
+        Raises:
+            ImportError: If matplotlib is not installed.
+
+        Returns:
+            matplotlib.Figure:
+                A figure of individual and accumulative HOP as a function of number of trials,
+                with 2-sigma confidence interval and 2/3 threshold.
+        """
+
+        if not HAS_MATPLOTLIB:
+            raise ImportError('The function plot_hop_accumulative needs matplotlib. '
+                              'Run "pip install matplotlib" before.')
+
+        if ax is None:
+            fig, ax = plt.subplots(figsize=figsize)
+        else:
+            fig = None
+
+        trial_list = np.arange(self._ntrials)  # x data
+        hop_list = []  # y data
+
+        for trial_index in range(self._ntrials):
+            circ_name = f'qv_depth_{depth}_trial_{trial_index}'
+            hop_list.append(self._heavy_output_prob_exp[circ_name])
+
+        hop_accumulative = np.cumsum(hop_list) / np.arange(1, self._ntrials+1)
+        two_sigma = 2 * (hop_accumulative * (1 - hop_accumulative) /
+                         np.arange(1, self._ntrials+1))**0.5
+
+        # plot two-sigma shaded area
+        ax.errorbar(trial_list, hop_accumulative, fmt="none", yerr=two_sigma, ecolor='lightgray',
+                    elinewidth=20, capsize=0, alpha=0.5, label='2$\\sigma$')
+        # plot accumulative HOP
+        ax.plot(trial_list, hop_accumulative, color='r', label='Cumulative HOP')
+        # plot inidivual HOP as scatter
+        ax.scatter(trial_list, hop_list, s=3, zorder=3, label='Individual HOP')
+        # plot 2/3 success threshold
+        ax.axhline(2/3, color='k', linestyle='dashed', linewidth=1, label='Threshold')
+
+        ax.set_xlim(0, self._ntrials)
+        ax.set_ylim(hop_accumulative[-1]-4*two_sigma[-1], hop_accumulative[-1]+4*two_sigma[-1])
+
+        ax.set_xlabel('Number of Trials', fontsize=14)
+        ax.set_ylabel('Heavy Output Probability', fontsize=14)
+
+        ax.set_title(f'Quantum Volume {2**depth} Trials', fontsize=14)
+
+        # re-arrange legend order
+        handles, labels = ax.get_legend_handles_labels()
+        handles = [handles[1], handles[2], handles[0], handles[3]]
+        labels = [labels[1], labels[2], labels[0], labels[3]]
+        ax.legend(handles, labels)
+
+        # Only close mpl figures in jupyter with inline backends
+        if fig:
+            if get_backend() in ['module://ipykernel.pylab.backend_inline',
+                                 'nbAgg']:
+                plt.close(fig)
+
+        return fig
+
+    def qv_success(self):
+        """Return whether each depth was successful (> 2/3 with confidence
+        level > 0.977 corresponding to z_value = 2) and the confidence level.
+
+        Returns:
+            list: List of list of 2 elements for each depth:
             - success True/False
-            - confidence
+            - confidence level
         """
 
         success_list = []
+        confidence_level_threshold = self.calc_confidence_level(z_value=2)
 
         for depth_ind, _ in enumerate(self._depths):
             success_list.append([False, 0.0])
             hmean = self._ydata[0][depth_ind]
-            if hmean > 2/3:
-                cfd = 0.5 * (1 +
-                             math.erf((hmean - 2/3)
-                                      / (1e-10 +
-                                         self._ydata[1][depth_ind])/2**0.5))
-                success_list[-1][1] = cfd
+            sigma = self._ydata[1][depth_ind]
+            z_value = self.calc_z_value(hmean, sigma)
+            confidence_level = self.calc_confidence_level(z_value)
+            success_list[-1][1] = confidence_level
 
-                if cfd > 0.975:
-                    success_list[-1][0] = True
+            if (hmean > 2/3 and confidence_level > confidence_level_threshold):
+                success_list[-1][0] = True
 
         return success_list
 
+    def calc_z_value(self, mean, sigma):
+        """Calculate z value using mean and sigma.
+
+        Args:
+            mean (float): mean
+            sigma (float): standard deviation
+
+        Returns:
+            float: z_value in standard normal distibution.
+        """
+
+        if sigma == 0:
+            # assign a small value for sigma if sigma = 0
+            sigma = 1e-10
+            warnings.warn('Standard deviation sigma should not be zero.')
+
+        z_value = (mean - 2/3) / sigma
+
+        return z_value
+
+    def calc_confidence_level(self, z_value):
+        """Calculate confidence level using z value.
+
+        Accumulative probability for standard normal distribution
+        in [-z, +infinity] is 1/2 (1 + erf(z/sqrt(2))),
+        where z = (X - mu)/sigma = (hmean - 2/3)/sigma
+
+        Args:
+            z_value (float): z value in in standard normal distibution.
+
+        Returns:
+            float: confidence level in decimal (not percentage).
+        """
+
+        confidence_level = 0.5 * (1 + math.erf(z_value/2**0.5))
+
+        return confidence_level
+
     def quantum_volume(self):
         """Return the volume for each depth.
 
